@@ -1,3 +1,3 @@
-import detector as detector
+import NuRadioReco.detector.detector as detector
 
-detector.buffer_db(in_memory=False, filename='arianna_detector_db.json')
\ No newline at end of file
+detector.buffer_db(in_memory=False, filename='arianna_detector_db.json')
