@@ -3,16 +3,17 @@ import pickle
 
 
 class RadioShower(NuRadioReco.framework.base_shower.BaseShower):
-    def __init__(self, station_ids=None):
+
+    def __init__(self, shower_id=0, station_ids=None):
         self.__station_ids = station_ids
-        super().__init__()
+        super().__init__(shower_id=shower_id)
 
     def get_station_ids(self):
         return self.__station_ids
 
     def has_station_ids(self, ids):
-        for id in ids:
-            if id not in self.__station_ids:
+        for station_id in ids:
+            if station_id not in self.__station_ids:
                 return False
         return True
 
